@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.49 2002/04/12 07:42:16 bazsi Exp $
+ * $Id: affile.c,v 1.50 2002/04/26 09:43:53 bazsi Exp $
  *
  ***************************************************************************/
  
@@ -73,9 +73,9 @@
 #include <pwd.h>
 #include <grp.h>
 #include <unistd.h>
-#include <stdio.h>
 #include <arpa/inet.h>
 #include <time.h>
+#include <stdio.h>
 #include "syslog-names.h"
 
 #include "affile.c.x"
@@ -161,7 +161,7 @@ static int do_init_affile_source(struct log_handler *c, struct syslog_config *cf
 	if (do_open_file(self->name, flags, -1, -1, -1, -1, -1, -1, 0, &fd)) {
 		lseek(fd, 0, SEEK_END);
 		self->src = io_read(make_io_fd(cfg->backend, fd, ol_string_use(self->name)), 
-			make_log_reader_ext(0, self->prefix, c), 
+			make_log_reader(0, self->prefix, cfg->log_msg_size, c), 
 			NULL);
 		self->res = REMEMBER_RESOURCE(cfg->resources, &self->src->super.super);
 		return ST_OK | ST_GOON;
@@ -260,9 +260,9 @@ do_init_dest_writer(struct log_handler *c, struct syslog_config *cfg, struct per
 	int fd, flags;
 	
   	if (self->owner->flags & AFFILE_PIPE)
-  		flags = O_RDWR | O_NOCTTY | O_NONBLOCK;
+  		flags = O_RDWR | O_NOCTTY | O_NONBLOCK | O_LARGEFILE;
   	else
-	  	flags = O_WRONLY | O_CREAT | O_APPEND | O_NOCTTY | O_NONBLOCK;
+	  	flags = O_WRONLY | O_CREAT | O_APPEND | O_NOCTTY | O_NONBLOCK | O_LARGEFILE;
 
         if (self->owner->remove_if_older > 0) {
                 /* remove (=unlink) if file is more than XXX days old */
@@ -533,11 +533,13 @@ struct macro_def {
 
 #define M_FULLHOST 36
 #define M_HOST     37
-#define M_PROGRAM  38
+#define M_FULLHOST_FROM 38
+#define M_HOST_FROM  39
+#define M_PROGRAM  40
 
-#define M_MESSAGE  39
+#define M_MESSAGE  41
 
-#define M_SOURCE_IP 40
+#define M_SOURCE_IP 42
 
 int append_string(char **dest, int *left, char *str, int length, int escape)
 {
@@ -600,11 +602,6 @@ void expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, in
 		length = snprintf(*dest, *left, "%02x", msg->pri);
 		break;
 	}
-	case M_FULLHOST: {
-		/* full hostname */
-		length = append_string(dest, left, msg->host->data, msg->host->length, escape);
-		break;
-	}
 	case M_SOURCE_IP: {
  		char *ip;
  		
@@ -619,23 +616,33 @@ void expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, in
 		length = append_string(dest, left, ip, strlen(ip), escape);
 		break;
 	}
+	case M_FULLHOST_FROM:
+	case M_FULLHOST: {
+		struct ol_string *host = (id == M_FULLHOST ? msg->host : msg->host_from);
+		/* full hostname */
+		length = append_string(dest, left, host->data, host->length, escape);
+		break;
+	}
+	case M_HOST_FROM:
 	case M_HOST: {
 		/* host */
-		UINT8 *p1 = memchr(msg->host->data, '@', msg->host->length);
+		struct ol_string *host = (id == M_HOST ? msg->host : msg->host_from);
+		UINT8 *p1;
 		UINT8 *p2;
 		int remaining;
 		
+		p1 = memchr(host->data, '@', host->length);
 		if (p1) 
 			p1++; 
 		else 
-			p1 = msg->host->data;
-                remaining = msg->host->length - (p1 - msg->host->data);
+			p1 = host->data;
+                remaining = host->length - (p1 - host->data);
 		p2 = memchr(p1, '/', remaining);
 		if (p2) {
 			length = MIN(p2 - p1, *left);
 		}
 		else {
-			length = MIN(*left, msg->host->length - (p1 - msg->host->data));
+			length = MIN(*left, host->length - (p1 - host->data));
 		}
 		length = append_string(dest, left, p1, length, escape);
 		break;
@@ -839,6 +846,8 @@ expand_macros(struct syslog_config *cfg, struct ol_string *template, int templat
  		{ "S_WEEKDAY", M_WEEKDAY_STAMP },
  		{ "S_UNIXTIME", M_UNIXTIME_STAMP },
 		
+		{ "HOST_FROM", M_HOST_FROM },
+		{ "FULLHOST_FROM", M_FULLHOST_FROM },
 		{ "HOST", M_HOST },
 		{ "FULLHOST", M_FULLHOST },
 
@@ -894,7 +903,7 @@ affile_find_writer(struct affile_dest *self,
 
 	if (self->flags & AFFILE_NO_EXPAND) {
 		if (!self->writers) {
-			self->writers = make_affile_dest_writer(self, self->template_fname);
+			self->writers = make_affile_dest_writer(self, ol_string_use(self->template_fname));
 			res = LOG_HANDLER_INIT(self->writers, self->cfg, NULL);
 			if (res & ST_QUIT)
 				return NULL;
