@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afinet.c,v 1.16 2002/04/12 07:42:16 bazsi Exp $
+ * $Id: afinet.c,v 1.17 2002/04/26 09:43:54 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -89,13 +89,13 @@ do_init_afinet_source_connection(struct log_handler *c,
 		notice("AF_INET client connected from %S, port %i\n", 
 		       inet->ip, inet->port);
 		io_read(self->client, 
-			make_log_reader(0, c), 
+			make_log_reader(0, NULL, cfg->log_msg_size, c), 
 			make_afsocket_source_close_callback(self));
 	}
 	else {
 		/* SOCK_DGRAM */
 		io_read(self->client, 
-			make_log_reader(1, c), 
+			make_log_reader(1, NULL, cfg->log_msg_size, c), 
 			make_afsocket_source_close_callback(self));
 	}
 	
