@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afunix.c,v 1.20 2002/02/28 13:05:37 bazsi Exp $
+ * $Id: afunix.c,v 1.21 2002/04/26 09:43:54 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -51,7 +51,7 @@ do_init_afunix_connection(struct log_handler *c,
 	CAST(afsocket_source_connection, self, c);
 
 	io_read(self->client, 
-		make_log_reader(0, c), 
+		make_log_reader(0, NULL, cfg->log_msg_size, c), 
 		make_afsocket_source_close_callback(self));
 	
 	return ST_OK | ST_GOON;
