@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: main.c,v 1.40 2002/04/03 08:37:02 bazsi Exp $
+ * $Id: main.c,v 1.41 2002/04/26 09:43:54 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -75,18 +75,19 @@ static void do_reread_config(struct callback *c)
 		io_callout(&self->backend->super, 0, c);
 		break;
 	case 1:
-		set_error_stream(2, 0);
 		if (CONFIG_INIT(self->backend->configuration, self->backend->persistent)) {
-			set_error_internal();
-			notice("new configuration initialized\n");
 			self->backend->newconfig = NULL;
 			self->backend->oldconfig = NULL;
 			kill_persistent_config(self->backend->persistent);
 			self->backend->persistent = NULL;
 			self->backend->super.reloading = 0;
+			if (!debug_flag) {
+				set_internal_cfg(self->backend->configuration);
+				set_error_internal();
+			}
+			notice("new configuration initialized\n");
 		}
 		else {
-			set_error_internal();
 			/* initializing the new configuration was not 
 			   successful, try to revert to the old one */
 			self->state++;
@@ -96,18 +97,20 @@ static void do_reread_config(struct callback *c)
 		}
 		break;
 	case 3:
-		set_error_stream(2, 0);
 		if (CONFIG_INIT(self->backend->configuration, self->backend->persistent)) {
-			set_error_internal();
+			kill_persistent_config(self->backend->persistent);
+			self->backend->persistent = NULL;
+			self->backend->super.reloading = 0;
+			if (!debug_flag) {
+				set_internal_cfg(self->backend->configuration);
+				set_error_internal();
+			}
 			notice("Initializing new configuration failed, reverting to old config.\n");
 		}
 		else {
 			/* this is a fatal error, but no stderr & no log output */
 			exit(127);
 		}
-		kill_persistent_config(self->backend->persistent);
-		self->backend->persistent = NULL;
-		self->backend->super.reloading = 0;
 		break;
 	}
 }
@@ -191,8 +194,7 @@ int main_loop(struct syslog_backend *backend)
 			CONFIG_DESTROY(backend->configuration, 0);
 			break;
 		}
-		if (reload_config && !backend->super.reloading) {
-			backend->super.reloading = 1;
+		if (reload_config) {
 			backend->newconfig = make_syslog_config(cfgfilename, &backend->super);
 			if (backend->newconfig) {
 				
@@ -217,13 +219,21 @@ int main_loop(struct syslog_backend *backend)
 			exit_main_loop = 1;
 		}
 		if (sighuprecvd) {
-			notice("SIGHUP received, restarting syslog-ng\n");
-			reload_config = 1;
-			r.backend = backend;
-			r.state = -1;
 			sighuprecvd = 0;
-			/* wait a second to flush buffers */
-			io_callout(&backend->super, 1, &r.super);
+			if (!backend->super.reloading) {
+
+				notice("SIGHUP received, restarting syslog-ng\n");
+				if (!debug_flag) {
+					set_error_stream(2, 0);
+					set_internal_cfg(NULL);
+				}
+				backend->super.reloading = 1;
+				reload_config = 1;
+				r.backend = backend;
+				r.state = -1;
+				/* wait a second to flush buffers */
+				io_callout(&backend->super, 1, &r.super);
+			}
 		}
 	}
 	if (!exit_main_loop) {
@@ -482,9 +492,14 @@ int main(int argc, char **argv)
 		setuid(uid);
 	}
 
-	if (do_fork) {
-
+	if (!debug_flag) {
 		set_error_internal();
+	}
+	else {
+		set_error_stream(2, 0);
+	}
+
+	if (do_fork) {
 		setup_fds();
 		setsid();
 	}
