@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: sources.c,v 1.32 2002/04/03 08:37:02 bazsi Exp $
+ * $Id: sources.c,v 1.33 2002/04/26 09:43:54 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -50,7 +50,7 @@
          (dgram simple UINT32)
          (prefix pointer UINT8)
 	 (pos simple UINT32)
-	 (buffer array UINT8 MAX_LOG_LINE)
+	 (buffer space UINT8)
          (next object log_handler)))
 */
 
@@ -136,9 +136,10 @@ do_read_line(struct read_handler **h,
 }
 
 struct read_handler *
-make_log_reader_ext(UINT32 dgram, 
-		    UINT8 *prefix,
-		    struct log_handler *next)
+make_log_reader(UINT32 dgram, 
+		UINT8 *prefix,
+		UINT32 max_log_line,
+		struct log_handler *next)
 {
 	NEW(log_reader, self);
 
@@ -146,17 +147,11 @@ make_log_reader_ext(UINT32 dgram,
 	self->dgram = dgram;
 	self->next = next;
 	self->prefix = prefix;
+	self->buffer = ol_space_alloc(max_log_line);
 	
 	return &self->super;
 }
 
-struct read_handler *
-make_log_reader(UINT32 dgram, 
-		struct log_handler *next)
-{
-	return make_log_reader_ext(dgram, NULL, next);
-}
-
 /* source_group */
 
 static struct ol_string *get_source_hostname(struct address_info *a, int usedns, int usefqdn, struct nscache *cache)
@@ -222,10 +217,12 @@ static void do_add_source_name(struct log_handler *c, struct log_info *logmsg)
 		return;
 	}
 	logmsg->source = c;
+	name = get_source_hostname(logmsg->saddr, 
+				   self->use_dns, self->use_fqdn,
+				   self->cache);
+	logmsg->host_from = name;
 	if (!self->keep_hostname || !logmsg->host) {
-		name = get_source_hostname(logmsg->saddr, 
-					   self->use_dns, self->use_fqdn,
-					   self->cache);
+		ol_string_use(name);
 		if (self->chain_hostnames) {
 			if (logmsg->flags & LF_LOCAL) {
 				/* local */
